@@ -7,6 +7,7 @@ from . import utils
 
 from .state import State
 from .controller import Controller
+from .ui import VirtualNodeManager
 from .protocol import CoreServer
 
 
@@ -30,7 +31,7 @@ class Server:
     :type options: Dict
     """
 
-    def __init__(self, name="trame", **options):
+    def __init__(self, name="trame", vn_constructor=None, **options):
         # Core internal variables
         self._server = None
         self._running_port = 0
@@ -42,6 +43,9 @@ class Server:
         # Controller
         self._controller = Controller(self.trigger, self.trigger_name)
 
+        # UI
+        self._ui = VirtualNodeManager(self, vn_constructor)
+
         # HTTP server
         self.serve = {}
 
@@ -287,6 +291,14 @@ class Server:
         """
         return self._controller
 
+    @property
+    def ui(self):
+        """
+        :return: The server VirtualNode manager
+        :rtype: trame_server.ui.VirtualNodeManager
+        """
+        return self._ui
+
     @property
     def running(self):
         """Return True if the server is currently starting or running."""
